<?php
/**
 * Implement theme metabox.
 *
 * @package Minimal Blog
 */

if ( ! function_exists( 'minimal_blog_add_theme_meta_box' ) ) :

    /**
     * Add the Meta Box
     *
     * @since 1.0.0
     */
    function minimal_blog_add_theme_meta_box() {

        $apply_metabox_post_types = array( 'post', 'page' );

        foreach ( $apply_metabox_post_types as $key => $type ) {
            add_meta_box(
                'minimal-blog-theme-settings',
                esc_html__( 'Single Page/Post Settings', 'minimal-blog' ),
                'minimal_blog_render_theme_settings_metabox',
                $type
            );
        }

    }

endif;

add_action( 'add_meta_boxes', 'minimal_blog_add_theme_meta_box' );

if ( ! function_exists( 'minimal_blog_render_theme_settings_metabox' ) ) :

    /**
     * Render theme settings meta box.
     *
     * @since 1.0.0
     */
    function minimal_blog_render_theme_settings_metabox( $post, $metabox ) {

        $post_id = $post->ID;
        $minimal_blog_post_meta_value = get_post_meta($post_id);

        // Meta box nonce for verification.
        wp_nonce_field( basename( __FILE__ ), 'minimal_blog_meta_box_nonce' );
        // Fetch Options list.
        $page_layout = get_post_meta($post_id,'minimal-blog-meta-select-layout',true);
    ?>
    <div id="minimal-blog-settings-metabox-container" class="minimal-blog-settings-metabox-container">
        <div id="minimal-blog-settings-metabox-tab-layout">
            <h4><?php echo __( 'Layout Settings', 'minimal-blog' ); ?></h4>
            <div class="minimal-blog-row-content">
                 <!-- Checkbox Field-->
                 <p>
                     <div class="minimal-blog-row-content">
                         <label for="minimal-blog-meta-checkbox">
                             <input type="checkbox" name="minimal-blog-meta-checkbox" id="minimal-blog-meta-checkbox" value="yes" <?php if ( isset ( $minimal_blog_post_meta_value['minimal-blog-meta-checkbox'] ) ) checked( $minimal_blog_post_meta_value['minimal-blog-meta-checkbox'][0], 'yes' ); ?> />
                             <?php _e( 'Check to remove featured image from detailed page/post', 'minimal-blog' )?>
                         </label>
                     </div>
                 </p>
            </div><!-- .minimal-blog-row-content -->
        </div><!-- #minimal-blog-settings-metabox-tab-layout -->
    </div><!-- #minimal-blog-settings-metabox-container -->

    <?php
    }

endif;



if ( ! function_exists( 'minimal_blog_save_theme_settings_meta' ) ) :

    /**
     * Save theme settings meta box value.
     *
     * @since 1.0.0
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post Post object.
     */
    function minimal_blog_save_theme_settings_meta( $post_id, $post ) {

        // Verify nonce.
        if ( ! isset( $_POST['minimal_blog_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['minimal_blog_meta_box_nonce'], basename( __FILE__ ) ) ) {
              return; }

        // Bail if auto save or revision.
        if ( defined( 'DOING_AUTOSAVE' ) || is_int( wp_is_post_revision( $post ) ) || is_int( wp_is_post_autosave( $post ) ) ) {
            return;
        }

        // Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
        if ( empty( $_POST['post_ID'] ) || $_POST['post_ID'] != $post_id ) {
            return;
        }

        // Check permission.
        if ( 'page' === $_POST['post_type'] ) {
            if ( ! current_user_can( 'edit_page', $post_id ) ) {
                return; }
        } else if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }

        $minimal_blog_meta_checkbox =  isset( $_POST[ 'minimal-blog-meta-checkbox' ] ) ? esc_attr($_POST[ 'minimal-blog-meta-checkbox' ]) : '';
        update_post_meta($post_id, 'minimal-blog-meta-checkbox', sanitize_text_field($minimal_blog_meta_checkbox));

    }

endif;

add_action( 'save_post', 'minimal_blog_save_theme_settings_meta', 10, 3 );